<?php
if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class Payment_List extends WP_List_Table {

	/** Class constructor */
	public function __construct() {

		parent::__construct( [
			'singular' => __( 'Payment', 'sp' ), //singular name of the listed records
			'plural'   => __( 'Payment', 'sp' ), //plural name of the listed records
			'ajax'     => false //does this table support ajax?
		] );

	}


	/**
	 * Retrieve payments data from the database
	 *
	 * @param int $per_page
	 * @param int $page_number
	 *
	 * @return mixed
	 */
	public static function get_payments( $per_page = 10, $page_number = 1 ) {

		global $wpdb;

		$sql = "SELECT * FROM packages";
		
        /*if ( ! empty( $_REQUEST['s'] ) ){
		$sql .= " WHERE position LIKE '%". $_REQUEST['s'] ."%' OR work_experience LIKE '%". $_REQUEST['s'] ."%' ";	
		} */
		if ( ! empty( $_REQUEST['orderby'] ) ) {
			$sql .= ' ORDER BY ' . esc_sql( $_REQUEST['orderby'] );
			$sql .= ! empty( $_REQUEST['order'] ) ? ' ' . esc_sql( $_REQUEST['order'] ) : ' DESC';
		}else{
			$sql .= ' ORDER BY id desc ';
		}

		$sql .= " LIMIT $per_page";
		$sql .= ' OFFSET ' . ( $page_number - 1 ) * $per_page;


		$result = $wpdb->get_results( $sql, 'ARRAY_A' );

		return $result;
	}


	/**
	 * Delete a customer record.
	 *
	 * @param int $id customer ID
	 */
	public static function delete_payment( $id ) {
		global $wpdb;

		$wpdb->delete(
			"submit_payment",
			[ 'id' => $id ],
			[ '%d' ]
		);
	}


	/**
	 * Returns the count of records in the database.
	 *
	 * @return null|string
	 */
	public static function record_count() {
		global $wpdb;

		$sql = "SELECT COUNT(*) FROM packages";

		return $wpdb->get_var( $sql );
	}


	/** Text displayed when no customer data is available */
	public function no_items() {
		_e( 'No payment avaliable.', 'sp' );
	}


	/**
	 * Render a column when no column specific method exist.
	 *
	 * @param array $item
	 * @param string $column_name
	 *
	 * @return mixed
	 */
	public function column_default( $item, $column_name ) {
		$wp_upload_dir = wp_upload_dir();
		switch ( $column_name ) {
			case 'item_name':
			case 'payment_amount':
			case 'payment_status':
			case 'txn_id':
			case 'businessname':
			case 'businessurl':
			    return $item[ $column_name ];
			default:
				return print_r( $item, true ); //Show the whole array for troubleshooting purposes
		}
	}

	/**
	 * Render the bulk edit checkbox
	 *
	 * @param array $item
	 *
	 * @return string
	 */
	function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="bulk-ids[]" value="%s" />', $item['id']
		);
	}


	/**
	 * Method for name column
	 *
	 * @param array $item an array of DB data
	 *
	 * @return string
	 */
	function column_item_name( $item ) { 

		$delete_nonce = wp_create_nonce( 'sp_delete_payment' );

		$title = '<strong>' . $item['item_name'] . '</strong>';

		$actions = [
			'delete' => sprintf( '<a href="?page=%s&action=%s&payment=%s&_wpnonce=%s">Delete</a>', esc_attr( $_REQUEST['page'] ), 'delete', absint( $item['id'] ), $delete_nonce )
		];

		return $title . $this->row_actions( $actions );
	}


	/**
	 *  Associative array of columns
	 *
	 * @return array
	 */
	function get_columns() {
		$columns = [
			'cb'      => '<input type="checkbox" />',
			'item_name'    => __( 'Package Name', 'sp' ),
			'payment_amount' => __( 'Amount', 'sp' ),
			'payment_status'    => __( 'Status', 'sp' ),
			'txn_id'    => __( 'Txn id', 'sp' ),
			'businessname'    => __( 'Business Name', 'sp' ),
			'businessurl'    => __( 'Business Url', 'sp' )
		];

		return $columns;
	}


	/**
	 * Columns to make sortable.
	 *
	 * @return array
	 */
	public function get_sortable_columns() {
		$sortable_columns = array(
			'item_name' => array( 'item_name', true )
		);

		return $sortable_columns;
	}

	/**
	 * Returns an associative array containing the bulk action
	 *
	 * @return array
	 */
	public function get_bulk_actions() {
		$actions = [
			'bulk-delete' => 'Delete'
		];

		return $actions;
	}


	/**
	 * Handles data query and filter, sorting, and pagination.
	 */
	public function prepare_items() {

		$this->_column_headers = $this->get_column_info();

		/** Process bulk action */
		$this->process_bulk_action();

		$per_page     = $this->get_items_per_page( 'payment_per_page', 10 );
		$current_page = $this->get_pagenum();
		$total_items  = self::record_count();

		$this->set_pagination_args( [
			'total_items' => $total_items, //WE have to calculate the total number of items
			'per_page'    => $per_page //WE have to determine how many items to show on a page
		] );

		$this->items = self::get_payments( $per_page, $current_page );
	}

	public function process_bulk_action() {

		//Detect when a bulk action is being triggered...
		if ( 'delete' === $this->current_action() ) {
			ob_start();
			// In our file that handles the request, verify the nonce.
			$nonce = esc_attr( $_REQUEST['_wpnonce'] );

			if ( ! wp_verify_nonce( $nonce, 'sp_delete_payment' ) ) {
				die( 'Go get a life script kiddies' );
			}
			else {
				self::delete_payment( absint( $_GET['payment'] ) );

		                // esc_url_raw() is used to prevent converting ampersand in url to "#038;"
		                // add_query_arg() return the current url
		                //wp_redirect( esc_url_raw(add_query_arg()) );
				//exit;
			}

		}

		// If the delete bulk action is triggered
		if ( ( isset( $_POST['action'] ) && $_POST['action'] == 'bulk-delete' )
		     || ( isset( $_POST['action2'] ) && $_POST['action2'] == 'bulk-delete' )
		) {
			ob_start();
			$delete_ids = esc_sql( $_POST['bulk-ids'] );

			// loop over the array of record IDs and delete them
			foreach ( $delete_ids as $id ) {
				self::delete_payment( $id );

			}

			// esc_url_raw() is used to prevent converting ampersand in url to "#038;"
		        // add_query_arg() return the current url
		        //wp_redirect( esc_url_raw(add_query_arg()) );
			//exit;
		}
		
		
	}
	
	
	

}


class Pack_Payment {

	// class instance
	static $instance;

	// Payment WP_List_Table object
	public $payment_obj;

	// class constructor
	public function __construct() {
		add_filter( 'set-screen-option', [ __CLASS__, 'set_screen' ], 10, 3 );
		add_action( 'admin_menu', [ $this, 'payment_menu' ] );
	}


	public static function set_screen( $status, $option, $value ) {
		return $value;
	}

	public function payment_menu() {

		$hook = add_menu_page(
			'Payment List',
			'Payment List',
			'manage_options',
			'wp_list_payment',
			[ $this, 'payment_settings_page' ]
		);
		
		
		add_action( "load-$hook", [ $this, 'screen_option' ] );

	}


	/**
	 * Payment settings page
	 */
	public function payment_settings_page() {
		?>
		<div class="wrap">
			<h2>Payment List</h2>

			<div id="poststuff">
				<div id="post-body" class="metabox-holder columns-1">
					<div id="post-body-content">
						<div class="meta-box-sortables ui-sortable">
						
							<form method="post">
							<div class="alignleft actions filteractions">
							
							</div>
								<?php
								$this->payment_obj->prepare_items();
								$this->payment_obj->display(); ?>
							</form>
						
						</div>
					</div>
				</div>
				<br class="clear">
				
			</div>
		</div>
	<?php
	}
	
	
	/**
	 * Screen options
	 */
	public function screen_option() {

		$option = 'per_page';
		$args   = [
			'label'   => 'Payments',
			'default' => 10,
			'option'  => 'payment_per_page'
		];

		add_screen_option( $option, $args );

		$this->payment_obj = new Payment_List();
	}


	/** Singleton instance */
	public static function get_instance() {
		if ( ! isset( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

}

add_action( 'init', function () {
	Pack_Payment::get_instance();
} );
?>